@@ -1,8 +1,24 @@
-from typing import List
+from typing import List, Optional, Any
+import decimal
 
 import abc
 
 
+def opt_decimal(s: str) -> Optional[decimal.Decimal]:
+    if s == "":
+        return None
+    else:
+        return decimal.Decimal(s)
+
+
+class InvalidFilename(Exception):
+    pass
+
+
+class UnsupportedState(Exception):
+    pass
+
+
 class UnexpectedRecordType(Exception):
     pass
 
@@ -22,12 +38,12 @@ class MissingFooter(Exception):
 class NetworkRow(abc.ABC):
     @staticmethod
     @abc.abstractmethod
-    def from_row(row: List[str]):
+    def from_row(row: List[str]) -> Any:
         ...
 
     @staticmethod
     @abc.abstractmethod
-    def record_type() -> int:
+    def get_record_type() -> int:
         ...
 
     def is_header(self) -> bool:
@@ -37,6 +53,10 @@ class NetworkRow(abc.ABC):
         return False
 
 
+class DetailRow(NetworkRow):
+    pass
+
+
 class HeaderRow(NetworkRow):
     def is_header(self) -> bool:
         return True
